diff --git a/source3/modules/vfs_ceph.c b/source3/modules/vfs_ceph.c
index e402ff1..85aad0e 100644
--- a/source3/modules/vfs_ceph.c
+++ b/source3/modules/vfs_ceph.c
@@ -750,8 +750,19 @@ static int cephwrap_ntimes(struct vfs_handle_struct *handle,
 			 struct smb_file_time *ft)
 {
 	struct utimbuf buf;
-	buf.actime = ft->atime.tv_sec;
-	buf.modtime = ft->mtime.tv_sec;
+	if (null_timespec(ft->atime))
+		buf.actime = smb_fname->st.st_ex_atime.tv_sec;
+	else
+		buf.actime = ft->atime.tv_sec;
+
+	if (null_timespec(ft->mtime))
+		buf.modtime = smb_fname->st.st_ex_mtime.tv_sec;
+	else
+		buf.modtime = ft->mtime.tv_sec;
+
+	if (buf.actime == smb_fname->st.st_ex_atime.tv_sec &&
+	    buf.modtime == smb_fname->st.st_ex_mtime.tv_sec)
+		return 0;
 	int result = ceph_utime(handle->data, smb_fname->base_name, &buf);
 	DEBUG(10, ("[CEPH] ntimes(%p, %s, {%ld, %ld, %ld, %ld}) = %d\n", handle, smb_fname_str_dbg(smb_fname),
 				ft->mtime.tv_sec, ft->atime.tv_sec, ft->ctime.tv_sec,
